Alea.A: Crack growth of aluminum A-alloy due mechanical fatigue efforts
Description
Crack growth of aluminum A-alloy due mechanical fatigue efforts. Alea.A is
a data frame composed of 262 rows y 3 columns.
Format
This data frame is composed of the following columns:
cycles- 21 vectors with times or cycles corresponding to each
specimen (overall 262 cycles).
cracks- 21 vectors with the crack lengths corresponding
to each specimen.
sample- 21 different specimens, each one repeated the number
of elements of "cycles" or "cracks".
Meeker, W., Escobar, L. (1998) Statistical Methods for Reliability Data.
John Wiley & Sons, Inc. New York.Details
Alea.A is composed of the crack length growth and number of cycles of 21
different specimens. It is detailed in Hudak et al. (1978) and referred
by Meeker and Escobar (1998) in table C.14.